<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=ay
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'access_interface_graphique' => 'Phuqata ajanu apnaqawir kuttaña',
	'access_mode_texte' => 'Ajanu juk’arayata sawutjam uñachayaña',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Aka qillqatax mayjachañawa',
	'admin_modifier_auteur' => 'Aka qillqirix mayjachañawa',
	'admin_modifier_breve' => 'Aka jisk’aptatax mayjachañawa',
	'admin_modifier_mot' => 'Aka imt’at arux mayjachañawa',
	'admin_modifier_rubrique' => 'Aka t’aqa mayjachaña',
	'admin_recalculer' => 'Aka laphi uñnaqax jichhaptayaña',
	'afficher_trad' => 'Jaqukipatanak taqir yatiyaña',
	'alerte_maj_impossible' => '&lt;b&gt;¡Amuyam!&lt;/b&gt; yatiy tamawix jichhaptawit MySQL uñjataru @version@ janiw lurañjamakiti, mä jan wal mayjt’aw imaqatatanakat yatiy tamawin ukataspaw. Ampi utjawimat apnaqirir arust’aw luram.',
	'analyse_xml' => 'Uñakipawi XML',
	'antispam_champ_vide' => 'Ampi akjawx ch’us jaytam:',
	'avis_archive_incorrect' => 'Qhanancht’ayir q’ipix janiw mä SPIP q’ipikiti.',
	'avis_archive_invalide' => 'qhanancht’ayir q’ipix janiw askikiti',
	'avis_attention' => '¡AMUYAM!',
	'avis_champ_incorrect_type_objet' => 'Akjawx sutix janiw askikiti @name@ uka kastataki @type@',
	'avis_colonne_inexistante' => 'Sayt’atax @col@ janiw utjkiti',
	'avis_erreur' => 'Pantjawi: aka manqhax uñjaña',
	'avis_erreur_connexion' => 'Naktaw ukjax pantjawiw utji',
	'avis_erreur_cookie' => 'Cookie jan wali ukata',
	'avis_erreur_fonction_contexte' => 'Sukt’awi ukjax pantjawi utji. Aka lurawinx janiw jawsañakiti.',
	'avis_erreur_mysql' => 'MySQL Pantjawi',
	'avis_erreur_sauvegarde' => '¡Yaqha qillqatat lurasinxa pantjawiw utji (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Jark’at qamawir mantawjirux mä jan wali utji',

	// B
	'barre_a_accent_grave' => 'Mä jach’aptata A jach’at arsuriyimpi uchantaña',
	'barre_aide' => 'Laphi uñnaq sumacht’añatakix kasta qillq thakhinak apnaqam',
	'barre_e_accent_aigu' => 'Mä  jach’aptata E jach’at arsuriyimpi uchantaña',
	'barre_eo' => 'Mä E O ukana uchantaña',
	'barre_eo_maj' => 'Mä E O jach’aptat ukana uchantaña',
	'barre_euro' => 'Chimpu uchantaña &#8364,',
	'barre_gras' => '{{Ch’iyaritat}} uskuña',
	'barre_guillemets' => '«comillas»kama uskuña',
	'barre_guillemets_simples' => '&#8220kama uskuña; comillas de segundo nivel&#65533',
	'barre_intertitre' => '{inter título} ukan mayjt’ayaña',
	'barre_italic' => '{K’umtat} uskuña',
	'barre_lien' => 'Mayjt’ayañan [chinu jach’a sawu-http://...]',
	'barre_lien_input' => 'Chinuman utjawip uñacht’ayam. Mä utjaw web uk uñacht’ayasmaw http://ukhama www.talsitio.org/q’ipi/ jan ukjax mä qillqata aka qamawin jakhu uñacht’ayam.',
	'barre_note' => 'Mayjt’ayañan [[kayu laphi uñnaq yatiyawi]]',
	'barre_quote' => 'Mä yatiyaw aytaña',
	'bouton_changer' => 'Turkaña',
	'bouton_chercher' => 'Thaqhaña',
	'bouton_choisir' => 'Chijllaña',
	'bouton_download' => 'Télécharger', # MODIF
	'bouton_enregistrer' => 'Imaña',
	'bouton_radio_desactiver_messagerie_interne' => 'Manqhax yatiyawirir suyt’ayaña',
	'bouton_radio_envoi_annonces' => 'Qillqat yatiyäwinak uk apayaña',
	'bouton_radio_non_envoi_annonces' => 'Yatiyawinakax jan apayañawa',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Machaq tantachat yatiyawinakax jan apayañawa',
	'bouton_recharger_page' => 'Aka laphi uñnaq jichhaptaña',
	'bouton_telecharger' => 'Apkataña',
	'bouton_upload' => 'Apkataña', # MODIF
	'bouton_valider' => 'Iyaw saña',

	// C
	'cal_apresmidi' => 'Jayp’u',
	'cal_jour_entier' => 'Jurnala',
	'cal_matin' => 'Arumanthi',
	'cal_par_jour' => 'Urut urut pacha chimpu',
	'cal_par_mois' => 'Phaxsit phaxsit pacha chimpu',
	'cal_par_semaine' => 'Simanat simanat pacha chimpu',
	'choix_couleur_interface' => 'Kulura',
	'choix_interface' => 'Ajanut ajllawi',
	'colonne' => 'Sayt’ata',
	'confirm_changer_statut' => 'Uñjataw, estado de elemento maytaw mayjaptayañ ¿munaskaktati sarantañxa?',
	'correcte' => 'Walikiwa',

	// D
	'date_aujourdhui' => 'Jichhuru',
	'date_avant_jc' => 'aC',
	'date_dans' => 'en @delai@',
	'date_de_mois_1' => '@j@ de @nommois@',
	'date_de_mois_10' => '@j@ uru @nommois@',
	'date_de_mois_11' => '@j@ de @nommois@',
	'date_de_mois_12' => '@j@ de @nommois@',
	'date_de_mois_2' => '@j@ de @nommois@',
	'date_de_mois_3' => '@j@ de @nommois@',
	'date_de_mois_4' => '@j@ de @nommois@',
	'date_de_mois_5' => '@j@ de @nommois@',
	'date_de_mois_6' => '@j@ de @nommois@',
	'date_de_mois_7' => '@j@ de @nommois@',
	'date_de_mois_8' => '@j@ de @nommois@',
	'date_de_mois_9' => '@j@ de @nommois@',
	'date_demain' => 'Arumanthi',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ a las @heure@',
	'date_fmt_jour_mois' => '@jour@ de @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ de @annee@',
	'date_fmt_mois_annee' => '@nommois@ de @annee@',
	'date_fmt_nomjour_date' => 'el @nomjour@ @date@',
	'date_heures' => 'Uras',
	'date_hier' => 'Masuru',
	'date_il_y_a' => 'hace @delai@',
	'date_jnum1' => '1ro',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'tuminku',
	'date_jour_1_abbr' => 'tum',
	'date_jour_1_initiale' => 't',
	'date_jour_2' => 'Lunisa',
	'date_jour_2_abbr' => 'lun',
	'date_jour_2_initiale' => 'l',
	'date_jour_3' => 'Martisa',
	'date_jour_3_abbr' => 'mar',
	'date_jour_3_initiale' => 'm',
	'date_jour_4' => 'Mirkulisa',
	'date_jour_4_abbr' => 'mir',
	'date_jour_4_initiale' => 'm',
	'date_jour_5' => 'Juywisa',
	'date_jour_5_abbr' => 'juy',
	'date_jour_5_initiale' => 'j',
	'date_jour_6' => 'Wirnisa',
	'date_jour_6_abbr' => 'wir',
	'date_jour_6_initiale' => 'v',
	'date_jour_7' => 'Sawaru',
	'date_jour_7_abbr' => 'saw',
	'date_jour_7_initiale' => 's',
	'date_jours' => 'Urunaka',
	'date_minutes' => 'Minutunaka',
	'date_mois' => 'Phaxsinaka',
	'date_mois_1' => 'Iniru',
	'date_mois_10' => 'Octuwri',
	'date_mois_11' => 'Nuwimri',
	'date_mois_12' => 'Dicimri',
	'date_mois_2' => 'Fiwriru',
	'date_mois_3' => 'Marzu',
	'date_mois_4' => 'Awril',
	'date_mois_5' => 'Mayu',
	'date_mois_6' => 'Junyu',
	'date_mois_7' => 'Julyu',
	'date_mois_8' => 'Agustu',
	'date_mois_9' => 'Siptimbri',
	'date_saison_1' => 'Juyphi pacha',
	'date_saison_2' => 'Junt’u pacha',
	'date_saison_3' => 'Jallu pacha',
	'date_saison_4' => 'Waña pacha',
	'date_semaines' => 'Simananaka',
	'dirs_commencer' => 'Uchantawixa chiqapin qalltañataki',
	'dirs_preliminaire' => 'Qallta: &lt;b&gt;Iyaws mantawx uk amtaña&lt;/b&gt;',
	'dirs_probleme_droits' => 'Iyaws mantawxa jan wali',
	'dirs_repertoires_absents' => '&lt;p&gt;&lt;b&gt;Arkir imañ q’ipinakax janiw jikiskiti:&lt;/b&gt;&lt;/p&gt;&lt;ul&gt;@bad_dirs@.&lt;/ul&gt; &lt;/b&gt;

&lt;p&gt;Jan wali qillqatawa jach’aptat qillqanakampi jisk’aptat qillqanakampicha ukaspawa. Mayamp uñjam imñan q’ipi sutipampi jach’aptat qillqanakampi jisk’aptat qillqanakampita aka jutiri uñjata ukhama. Jan ukasti imñan q’ipix turkam softweramanti FTPta, jan wali askichañataki.

Uk lurasinsti jutir imañ q’ipinaka jikitawa.&lt;/p&gt;

  &lt;p&gt;Cuando hayas hecho esta operación podrás     ',
	'dirs_repertoires_suivants' => '&lt;p&gt;&lt;b&gt;Jutir imañ q’ipinakax janiw qillqañatakikiti:&lt;/b&gt;&lt;/p&gt;&lt;ul&gt;@bad_dirs@.&lt;/ul&gt;

&lt;p&gt;Aka jan wali askichañatakix apnaqañamaw mä FTP apnaqiri mantawx iyawsa turkañatakix sapa mayn imañ q’ipinakaru aytata. Kunamti luraña ukax qhanañchatawa uchantaw qillqat irpirina.&lt;/p&gt;

&lt;p&gt;Una vez terminado este proceso, podrás ',
	'double_occurrence' => 'Pä lurawi', # MODIF

	// E
	'envoi_via_le_site' => 'Qamawitkam apayaña',
	'erreur' => 'Pantjawi',
	'erreur_balise_non_fermee' => 'Qhipir markhax jan jist’antata:',
	'erreur_texte' => 'Pantjawinaka',

	// F
	'fichier_introuvable' => 'Q’ipix janiw jiskiskiti @fichier@', # MODIF
	'form_deja_inscrit' => 'Qillqataxtaw.',
	'form_email_non_valide' => 'Aruskipayirimanx utjawipax janiw walikiti',
	'form_forum_access_refuse' => 'Aka qamawirux mantawimax janiw utjiti',
	'form_forum_bonjour' => 'kamisaki @nom@,',
	'form_forum_email_deja_enregistre' => 'Aka aruskipayirit utjawix qillqt’ataxiwa ukatx imt’awimx lurasmaw',
	'form_forum_identifiant_mail' => 'Machaq uñacht’ayirima apayapxtwa aruskipayirita.',
	'form_forum_identifiants' => 'Sapa maynit uñacht’ayiri',
	'form_forum_indiquer_nom_email' => 'Akar sutim uñachayam ukhamarak aruskipayirim uñachayam. Jank’akiw juman uñacht’ayirim apayanitam',
	'form_forum_login' => 'Uñt’ayasiwi:',
	'form_forum_message_auto' => '(Akax mä justupak yatiyawiwa)',
	'form_forum_pass' => 'Imt’awi:',
	'form_forum_probleme_mail' => 'Aruskipayirix jan waliwa: janiw uñacht’ayirix apayañjamakiti',
	'form_forum_voici1' => 'Esta es tu identificación para participar
en los foros del sitio \\&quot;@nom_site_spip@\\&quot; (@adresse_site@):',
	'form_forum_voici2' => 'Esta es tu identificación para proponer artículos
en el sitio \\&quot;@nom_site_spip@\\&quot; (@adresse_login@):   ',
	'form_indiquer_email' => 'Utjawi aruskipayirimat uñachayam',
	'form_indiquer_nom' => 'Sutim uñachayam',
	'form_indiquer_nom_site' => 'Web qamawimat suti uñachayam',
	'form_pet_deja_enregistre' => 'Aka qamawix qillqt’ataxiwa',
	'form_pet_signature_pasprise' => 'Iyawsamax janiw qillqaskiti.',
	'form_prop_confirmer_envoi' => 'Apawi iyaw sañapuni',
	'form_prop_description' => 'Uñt’ayawi/amuyawi',
	'form_prop_enregistre' => 'Amtatamax qillqataxiwa, iyaw sapkani khitinakatix apnaqapxi aka qamawxa ukatwa naktat uñstani.',
	'form_prop_envoyer' => 'Mä yatiyaw apayaña',
	'form_prop_indiquer_email' => 'Mä aruskipayirin iyaw sat utjawip uk uñachayam',
	'form_prop_indiquer_nom_site' => 'Qamawin sutip uñachayama.',
	'form_prop_indiquer_sujet' => 'Yatsuw uñachayaña',
	'form_prop_message_envoye' => 'Yatiyaw apayata',
	'form_prop_non_enregistre' => 'Amuyt’awimax janiw qillqatakiti.',
	'form_prop_sujet' => 'Yatsuwi',
	'form_prop_url_site' => 'Qamawin (URL) utjawipa', # MODIF
	'forum_non_inscrit' => 'Janiw qillqataktati, utjawich imt’atach pantjatawa.',
	'forum_par_auteur' => 'lurata @auteur@',
	'forum_titre_erreur' => 'Pantjata...',

	// I
	'ical_texte_rss_articles' => '«Backend» q’ipix aka qamawin qillqatanakata, utjawin jikisi:',
	'ical_texte_rss_articles2' => 'Ukhamarak «backend» q’ipinak jikismaw qillqatanakatakix sapa t’aqat aka sutinchatata: ',
	'ical_texte_rss_breves' => 'Ukhamarak mä q’ipi kawkintix jisk’aptatanak qamawin utji. T’aqa jakhuwi qhananchasa, jisk’aptatanakaki jikisispa.',
	'icone_a_suivre' => 'Lurawinakajaxa',
	'icone_admin_site' => 'Qamaw apnaqawi',
	'icone_agenda' => 'Pachachimpu lurawinaka',
	'icone_aide_ligne' => 'Naktata yanapaña',
	'icone_articles' => 'Qillqatanaka',
	'icone_auteurs' => 'Qillqirinaka',
	'icone_brouteur' => 'Jank’aki tuyuwi',
	'icone_configuration_site' => 'Qamaw uñtayawi',
	'icone_configurer_site' => 'Qamaw uñtayaña',
	'icone_creer_nouvel_auteur' => 'Mä machaq qillqir uñstayaña',
	'icone_creer_rubrique' => 'Mä t’aqa uñstayaña',
	'icone_creer_sous_rubrique' => 'Mä sullkir t’aq uñstayaña
',
	'icone_deconnecter' => 'T’aqaqtasiña',
	'icone_discussions' => 'Amuykipañanaka',
	'icone_doc_rubrique' => 'T’aqanakan qillqa q’ipinaka',
	'icone_ecrire_article' => 'Machaq qillqata',
	'icone_edition_site' => 'Qamaw askiptawi',
	'icone_gestion_langues' => 'Arunakat apnaqawi',
	'icone_informations_personnelles' => 'Sapa maynit yatiyawinaka
',
	'icone_interface_complet' => 'Phuqat ajanu',
	'icone_interface_simple' => 'Mä ajanuki',
	'icone_maintenance_site' => 'Qamawit uñjawi',
	'icone_messagerie_personnelle' => 'Sapa maynit yatiyañanaka',
	'icone_repartition_debut' => 'Qalltatpach lakiraw uñachaña',
	'icone_rubriques' => 'T’aqanaka',
	'icone_sauver_site' => 'Qamawit mä jarkat qillqaqa luraña',
	'icone_site_entier' => 'Taqpach qamawi',
	'icone_sites_references' => 'Aytat qamawinak',
	'icone_statistiques' => 'Qamawit tantiyatanaka',
	'icone_suivi_activite' => 'Qamawit uñch’ukiwi',
	'icone_suivi_actualite' => 'Qamawin jilawi',
	'icone_suivi_pettions' => 'Mayitanakat apnaqawi',
	'icone_suivi_revisions' => 'Qillqatanakat mayjaptatanaka',
	'icone_supprimer_document' => 'Aka qillqa q’ip apaqaña',
	'icone_supprimer_image' => 'Aka salta apaqaña',
	'icone_tous_articles' => 'Taqpach qillqatanakama',
	'icone_tous_auteur' => 'Taqpach qillqirinaka',
	'icone_visiter_site' => 'Aka qamaw tumpaña', # MODIF
	'icone_voir_en_ligne' => 'Naktat uñjaña',
	'img_indisponible' => 'Salta wakita',
	'impossible' => 'janipini',
	'info_a_suivre' => 'NAN LURAWINAKAJAXA',
	'info_acces_interdit' => 'Mantawj jark’ata',
	'info_acces_refuse' => 'Mantawj janiw sata',
	'info_action' => 'Lurawi: @action@',
	'info_administrer_rubriques' => 'Aka t’aqxa ukhamarak sullkir t’aqanakxa apnaqasmaw',
	'info_adresse_non_indiquee' => '¡yant’añ utjawxa uñachayapxistaw!',
	'info_aide' => 'YANAPA',
	'info_ajouter_mot' => 'Aka aru yapt’aña',
	'info_annonce' => 'Yatiyawi',
	'info_annonces_generales' => 'Jach’a yatiyawinaka',
	'info_article_propose' => 'Qillqatanak amtata',
	'info_article_publie' => 'Qillqat yatiyata',
	'info_article_redaction' => 'Qillqat lurasiskiwa',
	'info_article_refuse' => 'Janiw sat qillqata',
	'info_article_supprime' => 'Qillqat apaqata',
	'info_articles' => 'Qillqatanaka',
	'info_articles_a_valider' => 'Qillqatanak iyaw sañataki',
	'info_articles_proposes' => 'Amtat qillqatanaka',
	'info_auteurs_nombre' => 'Qillqirinaka:',
	'info_authentification_ftp' => 'Iyasawi (por FTP).',
	'info_breves_2' => 'jisk’aptatanaka',
	'info_connexion_refusee' => 'Arust’awix janiw satakiti',
	'info_contact_developpeur' => 'Mä prucramaturamp aruskipt’añamawa.',
	'info_contenance' => 'Aka qamawinx utjiwa:',
	'info_contribution' => 'Aruskipañat yanapawinaka', # MODIF
	'info_copyright' => '@spip@ mä software libre lakiratawa @lien_qpl@.',
	'info_copyright_doc' => 'Juk’amp yatxatañatakix qamaw uñjaña <a href=\'http://www.spip.net/es\'>http://www.spip.net/es</a>.   ', # MODIF
	'info_copyright_gpl' => 'GLP iyaw sakiñampi',
	'info_cours_edition' => 'Qillqatanakamax qillqt’asiskiwa', # MODIF
	'info_creer_repertoire' => 'Mä q’ipi jan ukjax mä imañ q’ipi akham sutin uñstayañamaxa',
	'info_creer_repertoire_2' => 'jach’a q’ipina <b>@repertoire@</b>, ukatxa ',
	'info_creer_vignette' => 'Jisk’itat justupak uñstayawi',
	'info_deplier' => 'Janatataña',
	'info_descriptif_nombre' => 'Uñicht’ayawinaka:',
	'info_description' => 'Uñicht’ayawi:',
	'info_description_2' => 'Uñicht’ayawi:',
	'info_dimension' => 'Ukch’a pachanaka',
	'info_ecire_message_prive' => 'Mä jark’at yatiyaw qillqaña',
	'info_email_invalide' => 'Aruskipayirin utjawix janiw walikiti.',
	'info_en_cours_validation' => 'Qillqatanakamax lurasiskiwa',
	'info_en_ligne' => 'Jichhax naktataskiwa',
	'info_envoyer_message_prive' => 'Mä jark’at yatiyaw aka qillqirir apayaña',
	'info_erreur_requete' => 'Mayiwin pantjawiw utji:',
	'info_erreur_squelette2' => 'Janiw ni mä ch’akha ch’akhas &lt;b&gt;@fichier@&lt;/b&gt; wakitakiti...   ',
	'info_erreur_systeme' => 'Apnaqawin pantjawiw utji (errno @errsys@)   ',
	'info_erreur_systeme2' => 'Disco duruxa phuqataspawa jan ukasti yatiyawinak pirwax janiw askikiti.<br />
<span style="color:red;">Pirwam <a href=\'@script@\'>askichañ yant’am</a>, jan ukax tampuma jikxatam.</span>  ',
	'info_fini' => '¡Tukuyata!',
	'info_format_image' => 'Saltan utt’ayata jisk’a saltanak apnaqawitaki @gd_formats@.',
	'info_format_non_defini' => 'utt’ayatax janiw uñacht’ayatakiti',
	'info_grand_ecran' => 'Phuqat salta',
	'info_image_aide' => 'Yanapa',
	'info_image_process_titre' => 'Kunjams jisk’aptatanak uñstayaña',
	'info_impossible_lire_page' => '¡Pantjata! &lt;/b&gt; Janiw laphi uñnaq liyiñjamakiti &lt;tt&gt;&lt;html&gt;@test_proxy@&lt;/html&gt;&lt;/tt&gt;  \\&quot;proxy\\&quot; &lt;tt&gt; ukampi',
	'info_installation_systeme_publication' => 'Apnaqaw yatiyat uchantawipa',
	'info_installer_documents' => 'Taqpach qillqa q’ipinak, jach’a q’ipin utjkix ukanaksustupak uchantasmax @upload@',
	'info_installer_ftp' => 'Iyaws apnaqirinakampi, q’ipinak uchantasmawa imañ q’ipina (FTP ukampi) @upload@ ukatxa akan  ajlliñataki.',
	'info_installer_images' => 'Saltanak utt’ayat uchantasmaw JPEG, GIF Y PNG.',
	'info_installer_images_dossier' => 'Imañ q’ipin saltanak uchantaña @upload@ ukat akjan ajlliñataki.',
	'info_interface_complete' => 'Phuqat ajanu',
	'info_interface_simple' => 'Má ajanuki',
	'info_joindre_document_article' => 'Aka qillqatanakarux kasta qillqa q’ipinak jaqkatasmaw',
	'info_joindre_document_rubrique' => 'Aka t’aqarux kasta qillqa q’ipinak jaqkatasmaw',
	'info_joindre_documents_article' => 'Aka t’aqarux kasta qillqa q’ipinak jaqkatasmaw',
	'info_l_article' => 'qillqataxa',
	'info_la_breve' => 'jisk’aptataxa',
	'info_la_rubrique' => 't’aqaxa',
	'info_langue_principale' => 'Qamawin aru',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ píxeles',
	'info_les_auteurs_1' => 'lurata @les_auteurs@',
	'info_logo_format_interdit' => 'Utt’ayat uñachir chimpunakak iyaw sataxa @formats@.',
	'info_logo_max_poids' => 'Uñachir chimpunakaxa phisnakiñapawa @maxi@ (q’ipix jathiwa @actuel@).',
	'info_mail_fournisseur' => 'Juman@churirima.com',
	'info_message_2' => 'YATIYAWI',
	'info_message_supprime' => 'Yatiyaw apaqata',
	'info_mise_en_ligne' => 'Qalltkis naktawix uka uru',
	'info_modification_parametres_securite' => 'tantiyt’at jark’aw mayjt’awinakapa',
	'info_mois_courant' => 'Aka jichha phaxsina:',
	'info_mot_cle_ajoute' => 'Jutir imt’at arux qillqataruw yapt’i',
	'info_multi_herit' => 'Armaqat aru',
	'info_multi_langues_soulignees' => '&lt;u&gt;Arunakaxa  sirqitanakaxa&lt;/u&gt; ajanutxa taqpach sawutanak mä jaqukipaw churi.

Sitix uka arunak ajlltax.Walja sapa mayanaka jach’a qamawita (urunaka, phuqañ laphinaka) justupak jaqukiptatani. Jani aru sirqitanakataki, qamawit arun  uñstani.', # MODIF
	'info_multilinguisme' => 'Walja arunaka',
	'info_nom_non_utilisateurs_connectes' => 'Sutimax janiw uñstkiti  jaqi tantanakan chinuta',
	'info_nom_utilisateurs_connectes' => 'Sutimax uñstiw jaqi tantanakan chinuta',
	'info_nombre_en_ligne' => 'Jichhax naktatawa',
	'info_non_resultat' => 'Thaqawitaqix janiw askichawinak jikiskiti \\&quot;@cherche_mot@\\&quot;',
	'info_non_utilisation_messagerie' => 'Manqhax yatiyaw jan apnaqaña.',
	'info_nouveau_message' => '&lt;b&gt;¡Ma machaq yatiyawinitawa!&lt;/b&gt;',
	'info_nouveaux_messages' => 'Utjtam @total_messages@ machaq yatiyawinaka',
	'info_numero_abbreviation' => 'N°',
	'info_pense_bete' => 'Katxasiñatak amtayiri',
	'info_petit_ecran' => 'Jisk’a uñachayiri',
	'info_pixels' => 'píxeles',
	'info_plusieurs_mots_trouves' => 'Walja imt’at arunak jiktan kunataki',
	'info_portfolio_automatique' => 'Justup imañ q’ìpi',
	'info_premier_resultat' => '[@debut_limit@ pnayraqat askichawinakat @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ nayraqat askichawinakat @total@]',
	'info_propose_1' => '[@nom_site_spip@] Amtata: @titre@',
	'info_propose_2' => 'Amtat qillqatanak
-----------------',
	'info_propose_3' => 'Qillqataxa \\&quot;@titre@\\&quot; amtatawa yatiyasiñapataki.',
	'info_propose_4' => 'Jawsthapitataw jiskht’añataki ukhamarak arst’añataki',
	'info_propose_5' => 'aruskipayirina. Utjawinx wakitaw:',
	'info_publie_01' => 'Qillqatax \\&quot;@titre@\\&quot; iyaw sataxiw luririta @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] YATIYATA: @titre@',
	'info_publie_2' => 'Qillqat yatiyata
----------------',
	'info_rechercher' => 'Thaqhaña',
	'info_rechercher_02' => 'Thaqhaña',
	'info_remplacer_vignette' => 'Nayrt’at jisk’a salta lantiñawa mä salta ajllitampi:',
	'info_sans_titre_2' => 'Jan sutichawimpi',
	'info_selectionner_fichier' => 'Jach’a q’ipitxa mä qillqa q’ip ajllismaw @upload@',
	'info_selectionner_fichier_2' => 'Mä qillqa q’ipi ajlliña...',
	'info_supprimer_vignette' => 'Aka salta apaqaña',
	'info_symbole_bleu' => '&lt;b&gt;Laram&lt;/b&gt; chimpux sañ muni sapa mayni amtawi mä amtawjamawa.   ',
	'info_symbole_jaune' => '&lt;b&gt;Q’illu&lt;/b&gt; chimpux sañ muniwa taqinir yatiyañataki qamaw apnaqirinakakiw mayjt’ayi ukhamarak taqpach qillqirinakat qhana uñjataw.',
	'info_symbole_vert' => '&lt;b&gt;Ch’uxña&lt;/b&gt; chimpux turkat yatiyawinaka yaqha qamaw jaqinakamp uk uñachayi',
	'info_telecharger_nouveau_logo' => 'Mä machaq uñachir chimpu apkataña:',
	'info_telecharger_ordinateur' => 'Computaturamat apkataña:',
	'info_tous_resultats_enregistres' => '[taqpach askichatawinak qillqatawa]',
	'info_tout_afficher' => 'Taqpach uñachayaña',
	'info_travaux_texte' => 'Aka qamawix janiraw kamachitakiti. Juk’amp nayraqatar kuttam.',
	'info_travaux_titre' => 'Qamawix mayxt’ayataskiw',
	'info_trop_resultat' => 'Thaqawitakix anchapuniw askichawinakax utji \\&quot;@cherche_mot@\\&quot;. Amuyunak uñachayam.',
	'info_utilisation_messagerie_interne' => 'Qamawit manqhax yatiyaw apnaqta.',
	'info_valider_lien' => 'Aka chinu iyaw saña',
	'info_verifier_image' => ', sumti saltanak inxtayapxi uk mayampi uñtam.',
	'info_vignette_defaut' => 'Nayrt’at salta',
	'info_vignette_personnalisee' => 'Kunamtix jumax jisk’a salt muntaxa',
	'info_visite' => 'tumpawi:',
	'info_vos_rendez_vous' => 'Aytatanakama',
	'infos_vos_pense_bete' => 'Amtatanakama', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Jisk’a saltanakak uñachayaña',
	'lien_afficher_texte_icones' => 'Jisk’a saltanakampi sawutanakampi uñachayaña',
	'lien_afficher_texte_seul' => 'Sawuk uñachayaña',
	'lien_liberer' => 'Antutjaña',
	'lien_liberer_tous' => 'aka qillqatanak antutjaña', # MODIF
	'lien_nouvea_pense_bete' => 'Machaq amtawirinaka',
	'lien_nouveau_message' => 'Machaq yatiyawi',
	'lien_nouvelle_annonce' => 'Machaq yatiyawi',
	'lien_petitions' => 'Mayiwi',
	'lien_popularite' => 'Juk’amp tumpata: @popularite@%',
	'lien_racine_site' => 'Qamaw qalltawi',
	'lien_reessayer' => 'mayamp yant’aña',
	'lien_repondre_message' => 'Aka yatiyawir jaysaña',
	'lien_supprimer' => 'Apaqaña',
	'lien_tout_afficher' => 'Taqpach uñachayaña',
	'lien_visite_site' => 'Aka qamaw tumpaña',
	'lien_visites' => '@visites@ tumpawinaka.',
	'lien_voir_auteur' => 'Aka qillqir uñjaña',
	'ligne' => 'Naktawi',
	'login_acces_prive' => 'ch’usawx jark’at mantawi',
	'login_autre_identifiant' => 'yaqha sutimpi yatiyt’asiña',
	'login_cookie_accepte' => 'Iyaw sañapatakix tuyuri kamachim (aka qamawitaki).',
	'login_cookie_oblige' => 'Aka qamawin uñt’ayasiñatakix, iyaw sañamaw \\&quot;cookies\\&quot; ukanakaru.',
	'login_deconnexion_ok' => 'Jan yatiyt’ir lurata.',
	'login_erreur_pass' => 'Imt’aw pantjata.',
	'login_espace_prive' => 'ch’usawx jark’ata',
	'login_identifiant_inconnu' => 'Apnaqirin sutipa «@login@» janiw uñt’atakiti.',
	'login_login' => 'Apnaqirin sutipa:',
	'login_login2' => 'Qalltawi (qamawir yatiyt’asiñataki apnaqirin sutipa):', # MODIF
	'login_login_pass_incorrect' => '(Apnaqirin sutipach imt’at jan wali.)',
	'login_motpasseoublie' => '¿imt’aw armata?',
	'login_non_securise' => 'Amuyam, aka phuqañ laphix janiw sum imatakiti. Janitix imt’atamx katuntat red ukan munktax, naktayam JavaScript en tu navegador y ',
	'login_nouvelle_tentative' => 'Mayamp yant’awi',
	'login_par_ici' => 'Akhanakan qillqatatawa...',
	'login_pass2' => 'Imt’awi:',
	'login_preferez_refuser' => '<b>Janitix munktaxa \\&quot;cookies\\&quot;</b>, yaqha chinuwit thakhi (jan sum jark’ata) ukax jumataxiw:',
	'login_recharger' => 'Aka laphi uñnaq phuqantaskakiña',
	'login_rester_identifie' => 'Mä qawqha urunak uñt’ayasiña', # MODIF
	'login_retour_public' => 'Jach’a qamaw utar kuttaña',
	'login_retour_site' => 'Jach’a qamaw utar kuttaña',
	'login_retoursitepublic' => 'jach’a qamaw uta',
	'login_sinscrire' => 'qillqayasiña',
	'login_test_navigateur' => 'tuyur yant’a/mayamp yatiyt’awi',
	'login_verifiez_navigateur' => '(Tuyurimax janiw imt’atam sum katkiti uk qhanstayam...)',

	// M
	'masquer_trad' => 'Jaqukipawinak imt’aña',
	'module_fichiers_langues' => 'Aru q’ipinaka',

	// N
	'navigateur_pas_redirige' => 'Janitix tuyurimax justupak chiqañchkitix, akjawx limt’am sarantaskakiñataki.',
	'numero' => 'Jakhuwi',

	// O
	'occurence' => 'Amuyuwi',
	'onglet_affacer_base' => 'Yatqalltaw chhaqayaña',
	'onglet_auteur' => 'Qillqiri',
	'onglet_contenu_site' => 'Qamawin utjirinaka',
	'onglet_evolution_visite_mod' => 'Mayjt’awi',
	'onglet_fonctions_avances' => 'Yatichsuwinak nayrt’ata',
	'onglet_informations_personnelles' => 'Sapa maynit yatiyawinakapa',
	'onglet_interactivite' => 'Aruskipayiri',
	'onglet_messagerie' => 'Yatiyawiri',
	'onglet_repartition_rubrique' => 'T’aqat t’aqat jalja',
	'onglet_save_restaur_base' => 'Yanapat qillqaqa ukhamarak yatqalltawit sumachawi',
	'onglet_vider_cache' => 'Caché ukax ch’usayaña',

	// P
	'pass_choix_pass' => 'Machaq imt’awim ajllima:',
	'pass_erreur' => 'Pantjata',
	'pass_erreur_acces_refuse' => '<b>Error:</b> aka qamawir janiw mantawimx utjiti ',
	'pass_erreur_code_inconnu' => '<b>Error:</b> aka chimpux janiw ni khiti aka qamawir mantawimp tumpirinkiti.',
	'pass_erreur_non_enregistre' => '<b>Error:</b> utjawixa <tt>@email_oubli@</tt> aka qamawinx janiw qillqatakiti.',
	'pass_erreur_non_valide' => '<b>Error:</b> aka utjawix <tt>@email_oubli@</tt> janiw iyaw satakiti',
	'pass_erreur_probleme_technique' => '&lt;b&gt;Pantjata:&lt;/b&gt; mä jan wali utjkipana, ukat janiw yatiyawix apayasiñ puyriskiti.

',
	'pass_espace_prive_bla' => 'Aka qamawinx ch’usawx jark’atax jist’aratawa, mä qillqawi ukhamata. Qillqataxtaxa ukjax yatxatasmaw qillqatanakax qillqasiski ukanaka, qillqatanak amtaña ukhamarak taqi aruskipañanakan arsusiñamaw.',
	'pass_forum_bla' => 'Mä aruskipañan qillqat jaqinakampi jupanakampiki ukan arsusiñ mayistawa.',
	'pass_indiquez_cidessous' => 'Ukatxa aruskipayirin utjawip kuna sutimpis nayraqatax qillqayasta uk uñachayam. Mä yatiyaw qatuqata kunamtix mantawjam kutiqayasita uka.',
	'pass_mail_passcookie' => '(Akax mä justup qamawiwa) Qamawir mantawx kutiqayasiñatakix  @nom_site_spip@  (@adresse_site@) arkir utjawir saraña: @sendcookie@ Ukar mä machaq imt’aw jumaw uskusma ukatxa mayamp qamawir chinusita.',
	'pass_mot_oublie' => 'Imt’aw armata',
	'pass_nouveau_enregistre' => 'Machaq imt’awimax qillqatawa.',
	'pass_nouveau_pass' => 'Machaq imt’awi',
	'pass_ok' => 'Waliki',
	'pass_oubli_mot' => 'Imt’aw armata',
	'pass_quitter_fenetre' => 'Aka wintan jaytanukuña',
	'pass_rappel_login' => 'Amtam: apnaqirit sutimax (login) «@login@».',
	'pass_recevoir_mail' => 'Aruskipayirit mä yatiyaw qatuqata kunjams mantwj qamawir kutiqayata.', # MODIF
	'pass_retour_public' => 'Jach’a qamaw utar kuttaña',
	'pass_rien_a_faire_ici' => 'Akjan janiw kuna lurañas utjkiti.',
	'pass_vousinscrire' => 'Aka qamawin qillqayasiña',
	'precedent' => 'nayrt’ata',
	'previsualisation' => 'Nayrt’at uñjat
',
	'previsualiser' => 'Nayt’at uñjaña',

	// S
	'spip_conforme_dtd' => 'SPIP ukax aka qillqa q’ip kipkakikix DOCTYPE ukhama amuyi:',
	'squelette' => 'ch’akha ch’akha',
	'squelette_inclus_ligne' => 'aka ch’akha ch’akha apkataña, naktawi',
	'squelette_ligne' => 'ch’akha ch’akha, naktawi',
	'stats_visites_et_popularite' => '@visites@ tumpatanaka; juk’amp tumpata: @popularite@ ',
	'suivant' => 'arkiri',

	// T
	'taille_ko' => '@taille@ KB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Ajanu ukamp yatistax ukjax, Ukjan limt’am «',
	'texte_actualite_site_2' => 'ajan phuqata',
	'texte_actualite_site_3' => '» kunans juk’amp lurasispa.',
	'texte_creation_automatique_vignette' => 'Aka qamawix iyaw sï jisk’a saltanak justupak uñstayañataki kunamti utt’ayat ukjama: 
@gd_formats@. Saltanak uchantkatax ukanakxa aka phuqañ laphimpi jisk’a salta @taille_preview@ píxeles ukaniniwa.',
	'texte_documents_associes' => 'Arkir qillqa q’ipinakaxa q’ipir mayachatawa, ukhamarusa janiw chiqaq uchantaskiti. Kunamtix jach’a qamawix utt’ayat ukhama, Qillqa q’ipinak apkatatjam ukham uñstanipxaspa.',
	'texte_erreur_mise_niveau_base' => 'Yatiyawinakat pirwax pantjawi utji jichhakiskapki ukja. Saltaxa &lt;b&gt;@fichier@&lt;/b&gt; janiw paskiti (qillqata @id_article@). Aka aytat qillqt’am mayampi jichhakiptaña yant’am ukat mayamp uñjam qillqatanakan saltax uñstki uka.',
	'texte_erreur_visiteur' => 'Ch’usawx jark’ataru mä uñacht’ayirimp janiw sï ukampi mantañ yant’a.',
	'texte_inc_auth_1' => 'Uñacht’ayastati login ukampi &lt;b&gt;@auth_login@&lt;/b&gt;, ukhamarus akax janiw yatiyawin utjkiti. Mayamp yant’am',
	'texte_inc_auth_2' => 'mayamp chinusim',
	'texte_inc_auth_3' => ', janiw wiñayataki jist’antasinxa ukhamarki mayampi tuyurima qalltasina.',
	'texte_inc_config' => 'Aka laphi uñnaqanakanja mayjt’awinakanxa qamawiman lurawipa amtayiwa. Janir uñtkasa iwxapsmawa jan arsuña apnaqawin lurawipampi SPIP.&lt;br /&gt;&lt;br /&gt;&lt;b&gt;Más ámpliamente, se recomienda vivamente dejar la gestión de estas páginas al o a la webmestre principal del sitio.&lt;/b&gt;   ',
	'texte_inc_meta_1' => 'Mä pantjawiw qillqat q’ipita apnaqawix jikitayna&lt;code&gt;@fichier@&lt;/code&gt;. Qamawit apnaqiri, ukham luraña.',
	'texte_inc_meta_2' => 'qillqat iyawsanak mayamp uñtaña',
	'texte_inc_meta_3' => 'Jach’a q’ipitxa <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'Qillqasiskiwa',
	'texte_statut_poubelle' => 'Wayaqaru',
	'texte_statut_propose_evaluation' => 'Arusthapiwir amtata',
	'texte_statut_publie' => 'Yatiyata',
	'texte_statut_refuse' => 'Janiw sata',
	'titre_ajouter_mot_cle' => 'Mä imt’at aru yapt’aña',
	'titre_cadre_raccourcis' => 'Jisk’a thakinaka...',
	'titre_changer_couleur_interface' => 'Ajanut kulur turkaña',
	'titre_image_admin_article' => 'Aka qillqat apnaqasmaw',
	'titre_image_administrateur' => 'Apnaqiri',
	'titre_image_aide' => 'Akar yanapam',
	'titre_image_auteur_supprime' => 'Qillqir apaqata',
	'titre_image_redacteur' => 'Qillqir jan mantawimpi',
	'titre_image_redacteur_02' => 'Qillqiri',
	'titre_image_visiteur' => 'Tumpiri',
	'titre_joindre_document' => 'Mä qillqa q’ip yapayaña',
	'titre_mots_cles' => 'Imt’at aru',
	'titre_probleme_technique' => 'UÑJAM: Mä jan waliw utji (jalanuqiri MySQL) janiw aka qamawir mantaykiti',
	'titre_publier_document' => 'AKA T’AQAN MÄ QILLQA Q’IP YATIYAÑA',
	'titre_statistiques' => 'Qamawit tantiyir',
	'titre_titre_document' => 'Qillqa q’ipin sutinchawi',
	'trad_reference' => '(aytat q’ipi)', # MODIF

	// Z
	'zbug_balise_b_aval' => ': bucle B chimputa juk’amp nayraru',
	'zbug_balise_inexistante' => 'error @from@: la baliza #@balise@ no existe', # MODIF
	'zbug_boucle' => 'bucle',
	'zbug_boucle_recursive_undef' => 'Bucle ukax maypamp mayampi jan uñacht’ayata', # MODIF
	'zbug_champ_hors_boucle' => 'Uka chiqar @champ@ bucle anqata',
	'zbug_champ_hors_motif' => 'Uka chiqaru @champ@ anqat bucle ukata @motif@', # MODIF
	'zbug_code' => 'chimpu',
	'zbug_critere_inconnu' => 'amuy jan uñt’ata @critere@ ', # MODIF
	'zbug_distant_interdit' => 'anqax jark’ata', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'repetidos en una tabla sin clave primaria simple', # MODIF
	'zbug_doublon_table_sans_index' => 'payacht’awinakaw utji mä uyu uyun jan utjawimpi', # MODIF
	'zbug_erreur_boucle_double' => 'BOUCLE@id@: pä arusthapiwi', # MODIF
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: jist’antat chimpux janiw utjkiti', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Kamachix bucle ukata pantjatawa', # MODIF
	'zbug_erreur_compilation' => 'Mayachawit pantjata',
	'zbug_erreur_execution_page' => 'pantja lurawi laphi uñnaqata', # MODIF
	'zbug_erreur_filtre' => 'Pantja: filtru &lt;b&gt;« @filtre@ »&lt;/b&gt; jani arusthapita', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} bucles ukanakaruki lurasi (FORUMS) jan ukjax (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'Ch’akha ch’akhan panjanaka',
	'zbug_info_erreur_squelette' => 'Qamawin pantja',
	'zbug_inversion_ordre_inexistant' => 'jan utjkiri kamachitathijrawi', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION jan amuyumpi {pagination}mä bucle mayamp mayampi apnaqata   ', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Apkatatawit tantiyata pantjatanaka', # MODIF
	'zbug_resultat' => 'askichawita',
	'zbug_serveur_indefini' => 'jalanuqiri SQL jan arusthapita', # MODIF
	'zbug_table_inconnue' => 'Uyu uyu SQL «@table@» jan uñt’at',
	'zxml_connus_attributs' => 'Jan uñt’atanak uñtawinaka',
	'zxml_de' => 'ukata',
	'zxml_inconnu_attribut' => 'Jan uñt’atanak uñtawinaka',
	'zxml_inconnu_balise' => 'Jan uñt’at chimpu',
	'zxml_inconnu_entite' => 'Jan uñt’at tama ',
	'zxml_inconnu_id' => 'ID jan uñt’ata',
	'zxml_mais_de' => 'ukhamata ',
	'zxml_non_conforme' => 'kun yanas janiw askikiti ',
	'zxml_non_fils' => 'Janiw wawapakiti ',
	'zxml_nonvide_balise' => 'jan ch’usa chimpu',
	'zxml_obligatoire_attribut' => 'uñt’awpini ukhamarusa chhaqhatawa ',
	'zxml_succession_fils_incorrecte' => 'yuqanakat panjawi sullka t’aqa',
	'zxml_survoler' => 'akar pasaña walik qillqatanak uñjañataki',
	'zxml_valeur_attribut' => 'uñt’awi',
	'zxml_vide_balise' => 'ch’usa chimpu',
	'zxml_vu' => 'nayra uñjata '
);
